Index: include/gpu/GrContext.h |
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h |
index 2a7c1383a0155c5c23659d92875fcf4fd7efa546..a34a43733a8fc18040e9f15424458eb954598519 100644 |
--- a/include/gpu/GrContext.h |
+++ b/include/gpu/GrContext.h |
@@ -423,10 +423,11 @@ private: |
GrAuditTrail fAuditTrail; |
- // TODO: have the CMM use drawContexts and rm this friending |
- friend class GrClipMaskManager; // the CMM is friended just so it can call 'drawingManager' |
- friend class GrDrawingManager; // for access to drawingManager for ProgramUnitTest |
+ // TODO: have the GrClipStackClip use drawContexts and rm this friending |
+ friend class GrClipStackClip; // for access to drawingManager |
+ friend class GrDrawingManager; // for access to drawingManager for ProgramUnitTest |
friend class GrContextPriv; |
+ |
GrDrawingManager* drawingManager() { return fDrawingManager; } |
GrContext(); // init must be called after the constructor. |